OBSOLETE
========

The **Plomino** package has been renamed
`Products.CMFPlomino <http://pypi.python.org/pypi/Products.CMFPlomino>`_
Please update your buildout eggs section.

Note: This egg is empty, it just declares a dependency to Products.CMFPlomino
(so buildout searching for 'Plomino' gets the accurate egg).

Introduction
============

Plomino is a powerful and flexible web-based application builder for Plone.

Credits
========
Companies
---------
|makinacom|_

  * `Planet Makina Corpus <http://www.makina-corpus.org>`_
  * `Contact us <mailto:python@makina-corpus.org>`_

.. |makinacom| image:: http://depot.makina-corpus.org/public/logo.gif
.. _makinacom:  http://www.makina-corpus.com
